==> aws-cdk-scala-kinesisanalytics_2.12-0.2.0-sources.jar: io/burkard/cdk/services/kinesisanalytics/ApplicationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisanalytics

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ApplicationConfigurationProperty {

  def apply(
    applicationCodeConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationCodeConfigurationProperty] = None,
    zeppelinApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ZeppelinApplicationConfigurationProperty] = None,
    applicationSnapshotConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationSnapshotConfigurationProperty] = None,
    flinkApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.FlinkApplicationConfigurationProperty] = None,
    sqlApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.SqlApplicationConfigurationProperty] = None,
    environmentProperties: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.EnvironmentPropertiesProperty] = None
  ): software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationConfigurationProperty.Builder)
      .applicationCodeConfiguration(applicationCodeConfiguration.orNull)
      .zeppelinApplicationConfiguration(zeppelinApplicationConfiguration.orNull)
      .applicationSnapshotConfiguration(applicationSnapshotConfiguration.orNull)
      .flinkApplicationConfiguration(flinkApplicationConfiguration.orNull)
      .sqlApplicationConfiguration(sqlApplicationConfiguration.orNull)
      .environmentProperties(environmentProperties.orNull)
      .build()
}

==> aws-cdk-scala-kinesisanalytics_2.12-0.5.0-sources.jar: io/burkard/cdk/services/kinesisanalytics/ApplicationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisanalytics

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ApplicationConfigurationProperty {

  def apply(
    applicationCodeConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationCodeConfigurationProperty] = None,
    zeppelinApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ZeppelinApplicationConfigurationProperty] = None,
    sqlApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.SqlApplicationConfigurationProperty] = None,
    environmentProperties: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.EnvironmentPropertiesProperty] = None,
    applicationSnapshotConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationSnapshotConfigurationProperty] = None,
    flinkApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.FlinkApplicationConfigurationProperty] = None
  ): software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisanalytics.CfnApplicationV2.ApplicationConfigurationProperty.Builder)
      .applicationCodeConfiguration(applicationCodeConfiguration.orNull)
      .zeppelinApplicationConfiguration(zeppelinApplicationConfiguration.orNull)
      .sqlApplicationConfiguration(sqlApplicationConfiguration.orNull)
      .environmentProperties(environmentProperties.orNull)
      .applicationSnapshotConfiguration(applicationSnapshotConfiguration.orNull)
      .flinkApplicationConfiguration(flinkApplicationConfiguration.orNull)
      .build()
}
